@@ -1677,11 +1677,11 @@ class Builder(Update):
                 initrd = path.join(boot_dn, initrd)
                 try:
                     with open(vmlinuz_orig, 'rb') as r_fd:
-                        with open(vmlinuz, 'w') as w_fd:
+                        with open(vmlinuz, 'wb') as w_fd:
                             w_fd.write(r_fd.read())
 
                     with open(initrd_orig, 'rb') as r_fd:
-                        with open(initrd, 'w') as w_fd:
+                        with open(initrd, 'wb') as w_fd:
                             w_fd.write(r_fd.read())
                 except (IOError, OSError) as e:
                     self.printERROR(str(e))
