@@ -71,7 +71,7 @@ class VariableClBuilderSplash(ReadonlyVariable):
 
 class DataVarsBuilderImage(LinuxDataVars):
     def variables(self):
-        l = super(DataVarsBuilderImage, self).variables()
+        l = super().variables()
         return l + [
             builder.VariableClBuilderPath(),
             builder.VariableClBuilderKernel(),
@@ -338,12 +338,12 @@ class VariableClBuilderTimezone(GrubOptionVariable,
 class VariableClBuilderX11Resolution(
     GrubOptionVariable, X11.VariableOsInstallX11ResolutionPreferred):
     def choice(self):
-        values = super(VariableClBuilderX11Resolution, self).choice()
+        values = super().choice()
         return [("auto", _("Auto"))] + [(x, x) for x in values]
 
     def check(self, value):
         if value != "auto":
-            super(VariableClBuilderX11Resolution, self).check(value)
+            super().check(value)
 
 
 class VariableClBuilderX11Composite(GrubOptionVariable,
